<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Haga clic para regresar a la aplicación</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Elementos</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Vuelva a intentarlo</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicar Podcast en YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Pizarra</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Lápiz</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Fondos</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Cambiar Fondo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Página anterior</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgArriba</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Página siguiente</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgAbajo</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Gestionar documentos</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Exploración web</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Línea pequeña</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Línea media</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Línea grande</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Borrador</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Borrador pequeño</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Borrador mediano</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Borrador grande</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Color</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Hacia delante</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Volver a cargar</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Volver a cargar página actual</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Cargar página de inicio</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Mostrar favoritos</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Añadir a favoritos</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Mostrar pizarra</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Borrar contenido</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Mostrar preferencias</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Mostrar biblioteca</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Mostrar escritorio</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Mostrar escritorio del ordenador</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Más grande</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Acercar</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Más pequeño</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Alejar</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nueva carpeta</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Crear una nueva carpeta</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nuevo documento</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Crear un nuevo documento</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importar un documento</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportar un Documento</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Abrir en la pizarra</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Abrir la página en la pizarra</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplicar el contenido seleccionado</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Eliminar el contenido seleccionado</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Añadir al documento de trabajo</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Añadir el contenido seleccionado al documento abierto</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Añadir contenido al documento</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Cambiar nombre</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Cambiar nombre al documento</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Mostrar Herramientas</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multipantalla</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Tamaño ancho (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Usar tamaño ancho de documento (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Tamaño regular (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Usar tamaño regular de documento (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Tamaño personalizado</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Usar tamaño personalizado de documento</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Detener carga</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Detener carga de la página web</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Dormir</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Poner la presentación en modo dormir</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclado virtual</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Mostrar teclado virtual</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Fondo claro liso</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Fondo claro cuadriculado</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Fondo oscuro liso</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Oscuro</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Fondo oscuro cuadriculado</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Grabar presentación en vídeo</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Iniciar grabación de pantalla</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Borrar elementos</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Borrar todos los elementos</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Borrar anotaciones</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Borrar todas las anotaciones</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Borrar página</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Borrar todos los elementos</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígrafo</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Anotar documento</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Borrar anotación</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Destacar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Selector</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Seleccionar y modificar objetos</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Mano</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Desplazar página</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Puntero láser</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Puntero láser virtual</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Dibujar líneas</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Escribir texto</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Captura</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturar parte de la pantalla</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Añadir a la página actual</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Añadir elemento a la página actual</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Añadir a la nueva página</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Añadir elemento a la nueva página</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Añadir a la biblioteca</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Añadir elemento a la biblioteca</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Crear una nueva página</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nueva página</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplicar página</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplicar la página actual</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importar página</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importar una página externa</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pausar la grabación de Podcast</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Config de podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Configurar grabación de podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Captura de elemento Flash</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Capturar contenido Flash</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Captura de contenido web</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Capturar contenido web</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Captura personalizada</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Captura de ventana</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Capturar una ventana</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Integrar contenido web</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Capturar contenido web integrable</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Mostrar en pantalla</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Mostrar pantalla principal en la pantalla del monitor</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Borrar todas las anotaciones</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importar simulación eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Comprobar actualizaciones</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Salir de OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Ocultar OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Ocultar aplicación OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interactuar con los elementos</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Borrar el Fondo</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Eliminar el fondo</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Abrir Tutorial</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Abrir el tutorial en página web</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation>Fondo claro con cuadrícula</translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation>Fondo oscuro con cuadrícula</translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation>Restablecer el tamaño de lacuadrícula</translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Se requiere autentificación</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autentificación de proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Conectar al Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Guardar nombre de usuario y contraseña para uso futuro</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Elemento ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>El formato de destino no permite este contenido</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Eliminar página</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>¿Está seguro de que quiere eliminar 1 página del documento seleccionado.&apos;%0?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Tamaño de página</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Nueva actualización disponible, ¿desea visitar la página web?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Ninguna actualización disponible</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Actualización disponible</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Board drawing...</source>
        <translation type="vanished">Dibujo de pizarra</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation>Tamaño de la cuadrícula</translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Fallo al descargar contenido %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descarga terminada</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Tipo de herramienta desconocida %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Tipo de contenido desconocido %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Añadir elemento</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Todos compatibles (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Borrar la página %1 del documento</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Página %1 eliminada</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Todas las operaciones con ficheros han fallado. Error al copiar los ficheros</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Agrupar</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Desagrupar</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Guardando documento</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Acaba de guardarse el documento...</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation>Borrando página %1</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Color</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Error al añadir la imagen a la biblioteca</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Imagen capturada</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation>Cargando página (%1/%2)</translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Almacenar propiedades en caché</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Capturar parte de la pantalla</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Capturar la pantalla</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Mostrar la paleta del lápiz</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Mostrar la pizarra en la pantalla secundaria</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Mostrar escritorio en la pantalla secundaria</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Mostrar OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Nueva carpeta</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Página %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Añadir carpeta de imágenes</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Añadir imágenes</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Añadir página desde archivo</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplicando documento %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Documento %1 copiado</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Eliminar página</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Eliminar documento</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">¿Está seguro de que desea eliminar el documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Vaciar papelera</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">¿Está seguro de que desea vaciar la papelera?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Vaciando papelera</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Papelera vaciada</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Eliminar carpeta</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">¿Está seturo de que desea eliminar la carpeta &apos;%1&apos; y todo su contenido?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">¡Ningún documento seleccionado!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Abrir archivo compatible</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importando archivo %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Fallo al importar archivo ...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importar todas las imágenes desde la carpeta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vaciar</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Abrir documento</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Añadir todas las imágenes al documento</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Todas las imágenes (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>¡La selección no contiene ningún archivo de imágenes!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>¿Está seguro de que desea eliminar %n página(s) del documento seleccionado &apos;%1&apos;?</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>La carpeta no contiene ningún fichero con imágenes</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Documentos sin título</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>El documento &apos;%1&apos; fue generado con una nueva versión de OpenBoard (%2). Al abrirlo, puede perder información. Desea continuar?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Está seguro de querer eliminar todos los documentos seleccionados?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Eliminar varios documentos</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation>
            <numerusform>%1 página copiada</numerusform>
            <numerusform>%1 páginas copiadas</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Borrar elementos</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>¿Está seguro de que desea eliminar el/los elemento(s) seleccionado(s)?</translation>
    </message>
    <message>
        <source>Title page</source>
        <translation>Página de título</translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>Objetos</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Todos los archivos compatibles (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Archivo %1 guardado</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Insertando página %1 de %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importación correcta</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>El archivo %1 se ha importado correctamente</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importando el fichero %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Página %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation>El nombre %1 ya está en uso.
Mantener este nombre reemplazará el documento.
Proporcionar un nuevo nombre creará un nuevo documento.</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>My documents</source>
        <translation>Mis documentos</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 páginas copiadas</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation>
            <numerusform>%1 páginas copiadas</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Borrar elementos</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation>¿Está seguro de que desea eliminar el/los elemento(s) seleccionado(s)?</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Copiando página %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (copia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Copiando página %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 páginas copiadas</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Descargando archivos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation>Página %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation>Página %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Han aparecido advertencias durante la exportación</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Falló la exportación</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation>No fue posible exportar al lugar seleccionado. No tiene los permisos necesarios para guardar el fichero.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation>Falló la exportación: no se puede escribir en el lugar seleccionado</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exportar a IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportar como fichero IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fallo en la exportación</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportar como archivo UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exportando %1 %2 de %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Exportar al formato OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Failed to export...</source>
        <translation>Fallo en la exportación...</translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation>Exportar como archivo UBX</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fallo de la exportación.</translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation>Exportar al formato OpenBoard UBX</translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportar como archivo PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportar a PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportar como archivo PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exportando página %1 de %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportación a PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportar como datos web</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportando documento...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Exportación satisfactoria.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Fallo de la exportación.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportar al explorador web</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Añadir a la página</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Definir como fondo</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Añadir a biblioteca</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Información del objeto</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Añadir a favoritos</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Compartir</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Regresar a la carpeta</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Eliminar de favoritos</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Crear nueva carpeta</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Comprobar los ficheros del sistema</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Imagen importada</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Ficheros de Audio</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Películas</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animaciones</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interactividades</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Formas</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Búsqueda Web</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Introduzca en nuevo nombre para la carpeta</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Cargando </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible en pantalla extendida</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Visible en pantalla extendida</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Ir a fuente de contenido</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation>Definir como fondo</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>No se pudo resolver el recurso multimedia</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Formato multimedia no soportado</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Servicio de reprodución multimedia no encontrado</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Error multimedia:</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Teclear Texto aquí&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Color de texto</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Editable</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Cargando...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Congelado</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformar como herramienta</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Formato de archivo común (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importando archivo %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Fallo en la importanción del archivo %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importación satisfactoria.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Fallo de la importación.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importando archivo %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importación satisfactoria.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Fallo de la importación del archivo %1.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation>Openboard (set de documentos) (*.ubx)</translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Formato de imagen (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Formato de documento portátil (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Fallo de la importación de PDF.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importando página %1 de %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Error el publicar vídeo en intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publicación en Intranet en progreso %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publicar</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Entrar</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Introduzca el nombre de usuario y la contraseña para &quot;%1&quot; en %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Fallo al iniciar sesión en proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Errores SSL: %1 %2 ¿Desea ignorar estos errores para este servidor?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Borrados Documentos Open-Sankore</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Mostrar este panel la próxima vez</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Siempre puede acceder al importador de documentos OpenBoard a través del panel Preferencias en la pestaña Sobre. Aviso, ya se han importado sus datos Open-Sankore, puede perder documentos OpenBoard actuales</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Los documentos de Open-Sankoré de su computador.Es posible importarlos a OpenBoard pulsando en el botón &quot;Continuar&quot; de la aplicación importadora.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(copiar)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Pérdida de depósito de documentos</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">perdió el acceso al repositorio de documentos &apos;%1&apos;. Desafortunadamente, la aplicación debe cerrarse para evitar la corrrupción de datos. También se pueden perder los últimos cambios. </translation>
    </message>
    <message>
        <source>Moving page to trash folder...</source>
        <translation type="vanished">Mover la página a la papelera</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation>OpenBoard perdió el acceso al repositorio de documentos &apos;%1&apos;. Desafortunadamente, la aplicación debe cerrarse para evitar la corrrupción de datos. También se pueden perder los últimos cambios. </translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francés</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Francés-Suizo</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Fallo al iniciar el codificador...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Ningún condificador de Podcast disponible...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Parte %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>en su escritorio...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>en carpeta %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast creado %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Error en la grabación de podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Entrada de audio predeterminada</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Ninguna grabación de audio</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pequeño</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Completo</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publicar en Intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publicar en Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation>OpenBoard Cast</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versión:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>El marcador es sensible a la presión</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Inicio de sesión en proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Nombre de usuario:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Contraseña:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publicar documento en la web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Título:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Descripción:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publicar</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Mis películas</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Visible la próxima vez</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Generando miniaturas de previsualización...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniaturas generadas...</translation>
    </message>
    <message>
        <source>loading thumbnail of page %1</source>
        <translation type="vanished">cargando miniaturas de la página %1</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation>Página %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Máscara</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Regla</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Brújula</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Transportador</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Triángulo</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Caché</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Página completa</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Actualizador de documento</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> los archivos requieren una actualización.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Ruta de la copia de seguridad:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Seleccione una carpeta para la copia de seguridad</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>¡Actualización de archivos satisfactoria!
Por favor, reinicie la aplicación para acceder a los documentos actualizados.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Ha ocurrido un error durante la actualización. Los archivos no han sido afectados.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultados de la actualización de archivos</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Actualizando archivo</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Por favor espere, el proceso de importación comenzará pronto...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recordármelo más tarde</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 llamado (método=%1, estado=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Fallo en la autentificación de YouTube.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Error al cargar el vídeo a YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Carga a YoutTube en progreso %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Autos &amp; Vehículos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Mascotas &amp; Animales</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Deportes</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Viajes &amp; Eventos</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Juego</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Comedia</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Personas &amp; Blogs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Noticias &amp; Política</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Entretenimiento</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Educación</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Howto &amp; estilo</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Sin fines de lucro &amp; Activismo</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Ciencia &amp; Tecnología</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Guardar archivo</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Descarga cancelada: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Error al abrir el archivo guardado: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Error al guardar: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 restante</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 de %2 (%3/seg) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>¿?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Detenido</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Descarga</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Descargas</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Anteriormente hoy</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 elementos</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nueva &amp;Pestaña</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Duplicar pestaña</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Cerrar pestaña</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Cerrar &amp; Otras pestañas</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recargar pestaña</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Volver a cargar todas las pestañas</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Pestañas cerradas recientemente</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Sin título)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Ninguna búsqueda reciente</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Búsquedas recientes</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Borrar búsquedas recientes</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Añadir al documento actual</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Error al cargar la página: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Descargar documento PDF: prefererías descargar el archivo PDF ou añadirlo al documento actual de OpenBoard?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Abrir en nueva pestaña</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publicar Podcast en YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Palabras clave</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Nombre de usuario de YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Contraseña de Youtube</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Al hacer clic en &apos;Descargar&apos; usted certifica que posee todos los derechos sobre el contenido o que está autorizado por el propietario a publicar el contenido en YouTube, y que éste cumple con los términos de servicio de YouTube que aparecen en&lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Restablece las credenciais al reiniciar</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Sobre fondo claro</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sobre fondo oscuro</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidad</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Ancho de línea</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Fuerte</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fino</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>El bolígrafo es sensible a la presión</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation>Mostrar vista previa del círculo de</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>Correo electrónico</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Diálogo</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="vanished">Título</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="vanished">Correo electrónico</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="vanished">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Descripción</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Documentos OpenBoard</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Fecha de creación</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Fecha de actualización</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Orden alfabético</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Orden de clasificación</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versión : …</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Configuración predeterminada</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Mostrar página con explorador externo</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Página de inicio:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Teclado virtual</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Tamaño de los botones del teclado:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Colocar en la parte superior (recomendado para computadores tipo tablet)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Colocar en la parte inferior (recomendado para pizarras blancas)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Mostrar texto debajo del botón</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paleta del lápiz</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígrafo</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Actualización del software</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Comprobar si hay actualizaciones del software al iniciarse</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licencias</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Mostrar el contenido de la página web en un monitor secundario o proyector</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Pantalla múltiple</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Intercambiar control de pantalla y vista de pantalla</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modalidad</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Comenzar en modalidad :</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Pizarra</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Nombre de usuario Proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Contraseña:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Importar de Open-Sankoré</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Compruebe si los datos de Open-Sankoré se pueden importar al iniciar</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Usar el teclado del sistema (recomendado)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Tamaño del botón del teclado virtual integrado</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Cuadrícula</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Sobre fondo oscuro</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacidad</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Sobre fondo claro</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Intercambiar control de pantalla y vista de pantalla</translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Capturar elemento flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Seleccionar un flash para capturar</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Nombre de la aplicación</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Crear aplicación</translation>
    </message>
</context>
</TS>
